# EPSIE

[![Build Status](https://travis-ci.com/cdcapano/epsie.svg?branch=master)](https://travis-ci.com/cdcapano/epsie)
[![Coverage Status](https://coveralls.io/repos/github/cdcapano/epsie/badge.svg)](https://coveralls.io/github/cdcapano/epsie)

EPSIE: an Embarrassingly Parallel Sampler for Inference Estimation

Quick installation:

```
pip install epsie
```
